import pytest
from pyredis_manager.async_manager import AsyncRedisManager

@pytest.fixture
def async_redis_manager():
    return AsyncRedisManager(db_aliases={"default": 0})

@pytest.mark.asyncio
async def test_async_set_and_get(async_redis_manager):
    client = async_redis_manager.get("default")
    await client.set("foo", "bar")
    value = await client.get("foo")
    assert value == b"bar"

@pytest.mark.asyncio
async def test_async_alias_limit(async_redis_manager):
    assert len(async_redis_manager.aliases) <= 16



from .manager import RedisManager, redis_manager
from .async_manager import AsyncRedisManager, async_redis_manager

__all__ = ["RedisManager", "redis_manager", "AsyncRedisManager", "async_redis_manager"]
__version__ = "0.1.0"



import asyncio
from itertools import islice
from typing import Dict, Optional
from redis.asyncio.client import Redis as AsyncRedis

try:
    from .map import redis_alias_map
except ImportError:
    redis_alias_map = {}


class AsyncRedisManager:
    def __init__(
        self,
        host: str = "localhost",
        port: int = 6379,
        db_aliases: dict = None,
        **kwargs
    ) -> None:
        self.clients: Dict[str, AsyncRedis] = {}
        self.host = host
        self.port = port

        if db_aliases is None: 
            db_aliases = dict(islice(redis_alias_map.items(), 16))
        else:
            db_aliases = dict(islice(db_aliases.items(), 16))
        self.aliases = db_aliases

        # init clients
        for alias, db_num in self.aliases.items():
            self.clients[alias] = AsyncRedis(host=host, port=port, db=db_num, **kwargs)

    def get(self, alias: str) -> Optional[AsyncRedis]:
        return self.clients.get(alias)

    def set_alias(self, alias: str, db_num: int) -> None:
        self.clients[alias] = AsyncRedis(host=self.host, port=self.port, db=db_num)
        self.aliases[alias] = db_num


async_redis_manager: AsyncRedisManager = AsyncRedisManager()


async def main():
    async_redis_manager.set_alias("default", 0)
    default = async_redis_manager.get("default")
    await default.set(name="fooo", value="barr", ex=300)
    val = await default.get("fooo")
    print(val)

asyncio.run(main())



import pytest
from pyredis_manager.manager import RedisManager

@pytest.fixture
def redis_manager():
    return RedisManager(db_aliases={"default": 0})

def test_set_and_get(redis_manager):
    client = redis_manager.get("default")
    client.set("foo", "bar")
    value = client.get("foo")
    assert value == b"bar"

def test_alias_limit(redis_manager):
    # 测试别名数量限制
    assert len(redis_manager.aliases) <= 16



from itertools import islice
from typing import Dict, Optional
from redis.client import Redis as SyncRedis

try:
    from .map import redis_alias_map
except ImportError:
    redis_alias_map = {}


class RedisManager:
    def __init__(
        self,
        host: str = "localhost",
        port: int = 6379,
        db_aliases: dict = None,
        **kwargs
    ) -> None:
        self.clients: Dict[str, SyncRedis] = {}
        self.host = host
        self.port = port
        
        if db_aliases is None: 
            db_aliases = dict(islice(redis_alias_map.items(), 16))
        else:
            db_aliases = dict(islice(db_aliases.items(), 16))
        self.aliases = db_aliases

        # init clients
        for alias, db_num in self.aliases.items():
            self.clients[alias] = SyncRedis(host=host, port=port, db=db_num, **kwargs)

    def get(self, alias: str) -> Optional[SyncRedis]:
        return self.clients.get(alias)

    def set_alias(self, alias: str, db_num: int) -> None:
        self.clients[alias] = SyncRedis(host=self.host, port=self.port, db=db_num)
        self.aliases[alias] = db_num


redis_manager: RedisManager = RedisManager()



from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as f:
    long_description = f.read()

setup(
    name="pyredis_manager",
    version="0.1.0",
    author="jack-cizon",
    author_email="jack20021213cn@gmail.com",
    description="A lightweight Redis client manager with sync/async support",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/jackcizon/pyredis_manager",
    packages=find_packages(),
    python_requires=">=3.8",
    install_requires=[
        "redis>=5.0.0",
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    include_package_data=True,
)
